# Changelog

## Version 0.6.0 24-02-2026
- Natural sort feature added.
- Transfer dev workflow to pure uv.
- Rotate image based on exif tags to avoid pixel conversion.
## Version 0.5.0 23-02-2026
- Bug on file input.
## Version 0.4.0 23-02-2026
- removed recursive selection of all images while using file as input.
## Version 0.3.0 23-02-2026
- added additional requirement to pyproject.toml
## Version 0.2.0 23-02-2026
- Added image counter
- Added go to image index feature
- added copy, move, Delete, Rotate
- Update extension feature.
- Datetime labels
## Version 0.1.0 - 19-02-2026
- Initial release
- Able to view photos.
- supports apple image extensions.
- Navigation supported.
- Image transform: Rotation possible.
- Rotations are considered inplace.
- Copy and Move functions available.
